@@ -1,12 +1,14 @@
 import time
+import logging
 
+log = logging.getLogger("timing")
 
 def timing(f):
     def wrap(*args):
         time1 = time.time()
         ret = f(*args)
         time2 = time.time()
-        print('{:s} function took {:.3f} ms'.format(f.__name__, (time2-time1)*1000.0))
+        log.info('{:s} function took {:.3f} ms'.format(f.__name__, (time2-time1)*1000.0))
 
         return ret
     return wrap
\ No newline at end of file
